==> 0.5.0.tar.gz: lib/widgets/senior_expansion_panel_list.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import './senior_button.dart';

class SeniorPanelData {
  final Widget headerInfo;
  final Widget? expandedInfo;
  final Color severityColor;
  bool isExpanded;
  final List<SeniorButton>? actions;

  SeniorPanelData({
    required this.headerInfo,
    this.expandedInfo,
    this.severityColor = SeniorColors.neutralColor100,
    this.isExpanded = false,
    this.actions,
  });
}

class SeniorExpansionPanelList extends StatelessWidget {
  final List<SeniorPanelData> list;
  final ExpansionPanelCallback expansionCallback;
  
  final Duration animationDuration = kThemeAnimationDuration;

  const SeniorExpansionPanelList({
    Key? key,
    required this.list,
    required this.expansionCallback,
  }) : super(key: key);

  bool _isChildExpanded(int index) {
    return list[index].isExpanded;
  }

  @override
  Widget build(BuildContext context) {
    final List<Widget> items = [];

    for (int index = 0; index < list.length; index += 1) {
      if(index != 0) {
        items.add(Divider(height: 15.0));
      }

      final Widget header = Row(
        children: <Widget>[
          Expanded(
            child: AnimatedContainer(
              duration: animationDuration,
              curve: Curves.fastOutSlowIn,
              child: ListTile(
                contentPadding: EdgeInsets.symmetric(horizontal: 16.0),
                title: list[index].headerInfo,
              ),
            ),
          ),
          ExpandIcon(
            isExpanded: _isChildExpanded(index),
            padding: const EdgeInsets.all(16.0),
            size: SeniorTypographyIconSize.CTA,
            onPressed: (bool isExpanded) {
              expansionCallback(index, isExpanded);
            },
          ),
        ],
      );

      final Widget body = AnimatedCrossFade(
        firstChild: Container(),
        secondChild: Container(
          width: double.maxFinite,
          padding: const EdgeInsets.symmetric(horizontal: 12.0, vertical: 16.0),
          child: Column(
            children: [
              list[index].expandedInfo ?? Container(),
              Padding(
                padding: const EdgeInsets.fromLTRB(0, 32.0, 0, 0),
                child: Row(
                  children: list[index].actions != null
                      ? list[index].actions!.asMap().map((i, action) => MapEntry(i, Expanded(
                          child: Container(
                            margin: EdgeInsets.fromLTRB(0, 0, i != list[index].actions!.length - 1 ? 12.0 : 0, 0),
                            child: action,
                          ),
                        ))).values.toList()
                      : [],
                ),
              ), 
            ],
          ),
        ),
        firstCurve: const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
        secondCurve: const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
        sizeCurve: Curves.fastOutSlowIn,
        crossFadeState: _isChildExpanded(index)
            ? CrossFadeState.showSecond
            : CrossFadeState.showFirst,
        duration: animationDuration,
      );

      items.add(
        Container(
          decoration: BoxDecoration(
            color: SeniorColors.neutralColor100,
            borderRadius: BorderRadius.all(Radius.circular(SeniorRadius.xbig)),
            gradient: LinearGradient(
              end: const Alignment(-0.97, 0),
              begin: const Alignment(-0.98, 0),
              colors: [this.list[index].severityColor, SeniorColors.neutralColor100],
            ),
          ),
          child: Column(
            children: <Widget>[
              header,
              body,
            ],
          ),
        ),
      );
    }

    return new Column(
      children: items,
    );
  }
}

==> 0.15.5.tar.gz: lib/widgets/senior_expansion_panel_list.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import './senior_button.dart';

class SeniorPanelData {
  final Widget headerInfo;
  final Widget? expandedInfo;
  final Color severityColor;
  bool isExpanded;
  final List<SeniorButton>? actions;

  SeniorPanelData({
    required this.headerInfo,
    this.expandedInfo,
    this.severityColor = SeniorColors.neutralColor100,
    this.isExpanded = false,
    this.actions,
  });
}

class SeniorExpansionPanelList extends StatelessWidget {
  final List<SeniorPanelData> list;
  final ExpansionPanelCallback expansionCallback;
  
  final Duration animationDuration = kThemeAnimationDuration;

  const SeniorExpansionPanelList({
    Key? key,
    required this.list,
    required this.expansionCallback,
  }) : super(key: key);

  bool _isChildExpanded(int index) {
    return list[index].isExpanded;
  }

  @override
  Widget build(BuildContext context) {
    final List<Widget> items = [];

    for (int index = 0; index < list.length; index += 1) {
      if(index != 0) {
        items.add(Divider(height: 15.0));
      }

      final Widget header = Row(
        children: <Widget>[
          Expanded(
            child: AnimatedContainer(
              duration: animationDuration,
              curve: Curves.fastOutSlowIn,
              child: ListTile(
                contentPadding: EdgeInsets.symmetric(horizontal: 16.0),
                title: list[index].headerInfo,
              ),
            ),
          ),
          ExpandIcon(
            isExpanded: _isChildExpanded(index),
            padding: const EdgeInsets.all(16.0),
            size: SeniorTypographyIconSize.CTA,
            onPressed: (bool isExpanded) {
              expansionCallback(index, isExpanded);
            },
          ),
        ],
      );

      final Widget body = AnimatedCrossFade(
        firstChild: Container(),
        secondChild: Container(
          width: double.maxFinite,
          padding: const EdgeInsets.symmetric(horizontal: 12.0, vertical: 16.0),
          child: Column(
            children: [
              list[index].expandedInfo ?? Container(),
              Padding(
                padding: const EdgeInsets.fromLTRB(0, 32.0, 0, 0),
                child: Row(
                  children: list[index].actions != null
                      ? list[index].actions!.asMap().map((i, action) => MapEntry(i, Expanded(
                          child: Container(
                            margin: EdgeInsets.fromLTRB(0, 0, i != list[index].actions!.length - 1 ? 12.0 : 0, 0),
                            child: action,
                          ),
                        ))).values.toList()
                      : [],
                ),
              ), 
            ],
          ),
        ),
        firstCurve: const Interval(0.0, 0.6, curve: Curves.fastOutSlowIn),
        secondCurve: const Interval(0.4, 1.0, curve: Curves.fastOutSlowIn),
        sizeCurve: Curves.fastOutSlowIn,
        crossFadeState: _isChildExpanded(index)
            ? CrossFadeState.showSecond
            : CrossFadeState.showFirst,
        duration: animationDuration,
      );

      items.add(
        Container(
          decoration: BoxDecoration(
            color: SeniorColors.neutralColor100,
            borderRadius: BorderRadius.all(Radius.circular(SeniorRadius.xbig)),
            gradient: LinearGradient(
              end: const Alignment(-0.97, 0),
              begin: const Alignment(-0.98, 0),
              colors: [list[index].severityColor, SeniorColors.neutralColor100],
            ),
          ),
          child: Column(
            children: <Widget>[
              header,
              body,
            ],
          ),
        ),
      );
    }

    return Column(
      children: items,
    );
  }
}
